=======
keyinfo
=======

Python library to convert X.509 certificates to and from W3C XML Signature KeyInfo structures


Description
===========

Python library to convert X.509 certificates to and from W3C XML Signature KeyInfo structures


